Class: Tennpipes::Mounter

Inherits:
Object
  • Object
show all
Defined in:
lib/tennpipes-base/mounter.rb

Overview

Represents a particular mounted Tennpipes application. Stores the name of the application (app folder name) and url mount path.

Examples:

Mounter.new("blog_app", :app_class => "Blog").to("/blog")
Mounter.new("blog_app", :app_file => "/path/to/blog/app.rb").to("/blog")

Defined Under Namespace

Classes: ApplicationWrapper, MounterException

Constant Summary collapse

DEFAULT_CASCADE =
[404, 405]

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ Mounter

Returns a new instance of Mounter.

Parameters:

Options Hash (options):

  • :app_class (Symbol) — default: Detected from name
  • :app_file (Symbol) — default: Automatically detected
  • :app_obj (Symbol) — default: Detected
  • :app_root (Symbol) — default: Directory of :app_file
  • :gem (Symbol)

    The gem to load the app from (Detected from name)



79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/tennpipes-base/mounter.rb', line 79

def initialize(name, options={})
  @name      = name.to_s
  @app_class = options[:app_class] || @name.camelize
  @gem       = options[:gem]       || @app_class.split("::").first.underscore
  @app_file  = options[:app_file]  || locate_app_file
  @app_obj   = options[:app_obj]   || app_constant || locate_app_object
  ensure_app_file! || ensure_app_object!
  @app_obj   = ApplicationWrapper.new(@app_obj, options) unless tennpipes_application?
  @app_root  = options[:app_root]  || (@app_obj.respond_to?(:root) && @app_obj.root || File.dirname(@app_file))
  @uri_root  = "/"
  @cascade   = options[:cascade] ? true == options[:cascade] ? DEFAULT_CASCADE.dup : Array(options[:cascade]) : []
  Tennpipes::Reloader.exclude_constants << @app_class
end

Instance Attribute Details

#app_classObject

Returns the value of attribute app_class.



66
67
68
# File 'lib/tennpipes-base/mounter.rb', line 66

def app_class
  @app_class
end

#app_fileObject

Returns the value of attribute app_file.



66
67
68
# File 'lib/tennpipes-base/mounter.rb', line 66

def app_file
  @app_file
end

#app_hostObject

Returns the value of attribute app_host.



66
67
68
# File 'lib/tennpipes-base/mounter.rb', line 66

def app_host
  @app_host
end

#app_objObject

Returns the value of attribute app_obj.



66
67
68
# File 'lib/tennpipes-base/mounter.rb', line 66

def app_obj
  @app_obj
end

#app_rootObject

Returns the value of attribute app_root.



66
67
68
# File 'lib/tennpipes-base/mounter.rb', line 66

def app_root
  @app_root
end

#cascadeObject

Returns the value of attribute cascade.



66
67
68
# File 'lib/tennpipes-base/mounter.rb', line 66

def cascade
  @cascade
end

#nameObject

Returns the value of attribute name.



66
67
68
# File 'lib/tennpipes-base/mounter.rb', line 66

def name
  @name
end

#uri_rootObject

Returns the value of attribute uri_root.



66
67
68
# File 'lib/tennpipes-base/mounter.rb', line 66

def uri_root
  @uri_root
end

Instance Method Details

#==(other) ⇒ Object

Makes two Mounters equal if they have the same name and uri_root.

Parameters:



197
198
199
# File 'lib/tennpipes-base/mounter.rb', line 197

def ==(other)
  other.is_a?(Mounter) && self.app_class == other.app_class && self.uri_root == other.uri_root
end

#app_constantTennpipes::Application

Returns the class object for the app if defined, nil otherwise.

Returns:



205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/tennpipes-base/mounter.rb', line 205

def app_constant
  klass = Object
  for piece in app_class.split("::")
    piece = piece.to_sym
    if klass.const_defined?(piece, false)
      klass = klass.const_get(piece)
    else
      return
    end
  end
  klass
end

#host(mount_host) ⇒ Object

Registers the mounted application onto Tennpipes for the given host.

Examples:

Mounter.new("blog_app").to("/blog").host("blog.tennpipes.org")
Mounter.new("blog_app").host("blog.tennpipes.org")
Mounter.new("catch_all").host(/.*\.tennpipes.org/)

Parameters:

  • mount_host (String)

    Host name.



125
126
127
128
129
# File 'lib/tennpipes-base/mounter.rb', line 125

def host(mount_host)
  @app_host = mount_host
  Tennpipes.insert_mounted_app(self)
  self
end

#map_onto(router) ⇒ Tennpipes::Router

Maps Tennpipes application onto a Tennpipes::Router. For use in constructing a Rack application.

Examples:

@app.map_onto(router)

Parameters:

Returns:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/tennpipes-base/mounter.rb', line 142

def map_onto(router)
  app_data = self
  app_obj = @app_obj
  if tennpipes_application?
    app_obj.set :uri_root,       app_data.uri_root
    app_obj.set :app_name,       app_data.app_obj.app_name.to_s
    app_obj.set :app_file,       app_data.app_file unless File.exist?(app_obj.app_file)
    app_obj.set :root,           app_data.app_root unless app_data.app_root.blank?
    app_obj.set :public_folder,  Tennpipes.root('public', app_data.uri_root) unless File.exist?(app_obj.public_folder)
    app_obj.set :static,         File.exist?(app_obj.public_folder) if app_obj.nil?
    app_obj.set :cascade,        app_data.cascade
  else
    app_obj.uri_root      = app_data.uri_root
    app_obj.public_folder = Tennpipes.root('public', app_data.uri_root) unless File.exist?(app_obj.public_folder)
  end
  app_obj.setup_application! # Initializes the app here with above settings.
  router.map(:to => app_obj, :path => app_data.uri_root, :host => app_data.app_host)
end

#named_routesArray

Returns the basic route information for each named route.

Returns:

  • (Array)

    Array of routes.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/tennpipes-base/mounter.rb', line 174

def named_routes
  app_obj.routes.map { |route|
    route_name = route.name.to_s
    route_name = 
      if route.controller
        route_name.split(" ", 2).map{|name| ":#{name}" }.join(", ")
      else
        ":#{route_name}"
      end
    name_array = "(#{route_name})"
    request_method = route.request_methods.first
    next if route.name.blank? || request_method == 'HEAD'
    original_path = route.original_path.is_a?(Regexp) ? route.original_path.inspect : route.original_path
    full_path = File.join(uri_root, original_path)
    OpenStruct.new(:verb => request_method, :identifier => route.name, :name => name_array, :path => full_path)
  }.compact
end

#routesObject

Returns the route objects for the mounted application.



164
165
166
# File 'lib/tennpipes-base/mounter.rb', line 164

def routes
  app_obj.routes
end

#tennpipes_application?Boolean

Returns:

  • (Boolean)


93
94
95
96
97
# File 'lib/tennpipes-base/mounter.rb', line 93

def tennpipes_application?
  @app_obj.ancestors.include?(Tennpipes::Application)
rescue NameError
  false
end

#to(mount_url) ⇒ Object

Registers the mounted application onto Tennpipes.

Examples:

Mounter.new("blog_app").to("/blog")

Parameters:

  • mount_url (String)

    Path where we mount the app.



108
109
110
111
112
# File 'lib/tennpipes-base/mounter.rb', line 108

def to(mount_url)
  @uri_root  = mount_url
  Tennpipes.insert_mounted_app(self)
  self
end