Class: Tennpipes::Reloader::Rack
- Inherits:
-
Object
- Object
- Tennpipes::Reloader::Rack
- Defined in:
- lib/tennpipes-base/reloader/rack.rb
Overview
This class acts as a Rack middleware to be added to the application stack. This middleware performs a check and reload for source files at the start of each request, but also respects a specified cool down time during which no further action will be taken.
Instance Method Summary collapse
-
#call(env) ⇒ Object
Invoked in order to perform the reload as part of the request stack.
-
#initialize(app, cooldown = 1) ⇒ Rack
constructor
A new instance of Rack.
Constructor Details
#initialize(app, cooldown = 1) ⇒ Rack
Returns a new instance of Rack.
10 11 12 13 14 |
# File 'lib/tennpipes-base/reloader/rack.rb', line 10 def initialize(app, cooldown=1) @app = app @cooldown = cooldown @last = (Time.now - cooldown) end |
Instance Method Details
#call(env) ⇒ Object
Invoked in order to perform the reload as part of the request stack.
17 18 19 20 21 22 23 |
# File 'lib/tennpipes-base/reloader/rack.rb', line 17 def call(env) if @cooldown && Time.now > @last + @cooldown Thread.list.size > 1 ? Thread.exclusive { Tennpipes.reload! } : Tennpipes.reload! @last = Time.now end @app.call(env) end |